"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var proxy = require("ui/core/proxy");
var dependencyObservable = require("ui/core/dependency-observable");
var layoutBaseModule = require("ui/layouts/layout-base");
var viewModule = require("ui/core/view");
var utils = require("utils/utils");
var trace = require("trace");
var gridLayout = require("ui/layouts/grid-layout");
var types = require("utils/types");
var labelModule = require("ui/label");
var observableArray = require("data/observable-array");
var weakEvents = require("ui/core/weak-event-listener");
var ITEM_VIEW = 'selectedItemView', ITEMS = 'items', SELECTED_INDEX = 'selectedIndex', MDL = 'materialDropdownList';
function onItemsPropertyChanged(data) {
    var mdl = data.object;
    mdl._onItemsPropertyChanged(data);
}
function onSelectedItemViewPropertyChanged(data) {
    var mdl = data.object;
    mdl._onSelectedItemTemplatePropertyChanged(data);
}
function onSelectedIndexPropertyChanged(data) {
    var mdl = data.object;
    mdl._onSelectedIndexPropertyChanged(data);
}
function generateDefaultLayoutContent(gv) {
    var col1 = new gridLayout.ItemSpec(1, gridLayout.GridUnitType.star), col2 = new gridLayout.ItemSpec(1, gridLayout.GridUnitType.auto), row1 = new gridLayout.ItemSpec(1, gridLayout.GridUnitType.auto), row2 = new gridLayout.ItemSpec(1, gridLayout.GridUnitType.auto), lblValue = new labelModule.Label(), lblUnderline = new labelModule.Label(), lblIcon = new labelModule.Label();
    lblValue.id = 'mdlSelectedValue';
    gv.cssClass = 'mdl-container';
    lblValue.cssClass = 'mdl-value';
    lblUnderline.cssClass = 'mdl-underline';
    lblIcon.cssClass = 'mdl-icon';
    gv.addColumn(col1);
    gv.addColumn(col2);
    gv.addRow(row1);
    gv.addRow(row2);
    gv.addChild(lblValue);
    gv.addChild(lblUnderline);
    gv.addChild(lblIcon);
    gridLayout.GridLayout.setColumn(lblValue, 0);
    gridLayout.GridLayout.setRow(lblValue, 0);
    gridLayout.GridLayout.setColumn(lblIcon, 1);
    gridLayout.GridLayout.setRowSpan(lblIcon, 2);
    gridLayout.GridLayout.setColumn(lblUnderline, 0);
    gridLayout.GridLayout.setRow(lblUnderline, 1);
    gridLayout.GridLayout.setColumnSpan(lblUnderline, 2);
}
var MaterialDropdownList = (function (_super) {
    __extends(MaterialDropdownList, _super);
    function MaterialDropdownList() {
        _super.call(this);
        this._isDirty = false;
        var gv = new gridLayout.GridLayout();
        gv.id = 'mdlLayout';
        this.selectedItemView = gv;
    }
    MaterialDropdownList.prototype._createUI = function () {
        this._android = this.selectedItemView.android;
        generateDefaultLayoutContent(this.selectedItemView);
    };
    Object.defineProperty(MaterialDropdownList.prototype, "android", {
        get: function () {
            return this._android;
        },
        enumerable: true,
        configurable: true
    });
    MaterialDropdownList.prototype.onLoaded = function () {
        trace.write(MDL + ".onLoaded()", MDL);
        _super.prototype.onLoaded.call(this);
    };
    Object.defineProperty(MaterialDropdownList.prototype, "selectedItemView", {
        get: function () {
            return this._getValue(MaterialDropdownList.selectedItemViewProperty);
        },
        set: function (value) {
            this._setValue(MaterialDropdownList.selectedItemViewProperty, value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MaterialDropdownList.prototype, "items", {
        get: function () {
            return this._getValue(MaterialDropdownList.itemsProperty);
        },
        set: function (value) {
            this._setValue(MaterialDropdownList.itemsProperty, value);
        },
        enumerable: true,
        configurable: true
    });
    MaterialDropdownList.prototype._onItemsChanged = function (data) {
        trace.write(MDL + "._onItemsChanged(" + data + ")", MDL);
        this._requestRefresh();
    };
    MaterialDropdownList.prototype._onItemsPropertyChanged = function (data) {
        trace.write(MDL + "._onItemsPropertyChanged(" + data.oldValue + " => " + data.newValue + ")", MDL);
        if (data.oldValue instanceof observableArray.ObservableArray) {
            weakEvents.removeWeakEventListener(data.oldValue, observableArray.ObservableArray.changeEvent, this._onItemsChanged, this);
        }
        if (data.newValue instanceof observableArray.ObservableArray) {
            weakEvents.addWeakEventListener(data.newValue, observableArray.ObservableArray.changeEvent, this._onItemsChanged, this);
        }
        this._requestRefresh();
    };
    MaterialDropdownList.prototype._onSelectedIndexPropertyChanged = function (data) {
        trace.write(MDL + "._onSelectedIndexPropertyChanged(" + data.oldValue + " => " + data.newValue, MDL);
        this._requestRefresh();
    };
    MaterialDropdownList.prototype._onSelectedItemTemplatePropertyChanged = function (pcd) {
        trace.write(MDL + "._onselectedItemViewPropertyPropertyChanged(" + pcd.oldValue + " => " + pcd.newValue + ")", MDL);
        if (pcd.oldValue instanceof layoutBaseModule.LayoutBase) {
            this._removeView(pcd.oldValue);
        }
        if (pcd.newValue instanceof layoutBaseModule.LayoutBase) {
            this._addView(pcd.newValue);
            pcd.newValue.on('tap', function () {
                console.log('TAPPED!');
            });
            if (pcd.newValue.id === 'mdlLayout') {
            }
        }
        this._requestRefresh();
    };
    MaterialDropdownList.prototype._requestRefresh = function () {
        trace.write(MDL + "._requestRefresh()", MDL);
        this._isDirty = true;
        if (this.isLoaded) {
            this.refresh();
        }
    };
    MaterialDropdownList.prototype.refresh = function () {
        trace.write(MDL + ".refresh()", MDL);
        if (types.isNullOrUndefined(this.items) || !types.isNumber(this.items.length)) {
            return;
        }
        if (this.selectedItemView.id === 'mdlLayout') {
        }
        this._isDirty = false;
    };
    MaterialDropdownList.prototype._getDataItem = function (index) {
        return this.items.getItem ? this.items.getItem(index) : this.items[index];
    };
    Object.defineProperty(MaterialDropdownList.prototype, "_childrenCount", {
        get: function () {
            var count = 0;
            if (this.selectedItemView) {
                count++;
            }
            return count;
        },
        enumerable: true,
        configurable: true
    });
    MaterialDropdownList.prototype._eachChildView = function (callback) {
        if (this.selectedItemView) {
            callback(this.selectedItemView);
        }
    };
    MaterialDropdownList.prototype.onLayout = function (left, top, right, bottom) {
        viewModule.View.layoutChild(this, this.selectedItemView, 0, 0, right - left, bottom - top);
    };
    MaterialDropdownList.prototype.onMeasure = function (widthMeasureSpec, heightMeasureSpec) {
        var result = viewModule.View.measureChild(this, this.selectedItemView, widthMeasureSpec, heightMeasureSpec);
        var width = utils.layout.getMeasureSpecSize(widthMeasureSpec);
        var widthMode = utils.layout.getMeasureSpecMode(widthMeasureSpec);
        var height = utils.layout.getMeasureSpecSize(heightMeasureSpec);
        var heightMode = utils.layout.getMeasureSpecMode(heightMeasureSpec);
        var widthAndState = viewModule.View.resolveSizeAndState(result.measuredWidth, width, widthMode, 0);
        var heightAndState = viewModule.View.resolveSizeAndState(result.measuredHeight, height, heightMode, 0);
        this.setMeasuredDimension(widthAndState, heightAndState);
    };
    MaterialDropdownList.itemsProperty = new dependencyObservable.Property(ITEMS, MDL, new proxy.PropertyMetadata(undefined, dependencyObservable.PropertyMetadataSettings.AffectsLayout, onItemsPropertyChanged));
    MaterialDropdownList.selectedItemViewProperty = new dependencyObservable.Property(ITEM_VIEW, MDL, new proxy.PropertyMetadata(undefined, dependencyObservable.PropertyMetadataSettings.AffectsLayout, onSelectedItemViewPropertyChanged));
    MaterialDropdownList.selectedIndexProperty = new dependencyObservable.Property(SELECTED_INDEX, MDL, new proxy.PropertyMetadata(undefined, dependencyObservable.PropertyMetadataSettings.AffectsLayout, onSelectedIndexPropertyChanged));
    return MaterialDropdownList;
}(viewModule.View));
exports.MaterialDropdownList = MaterialDropdownList;
//# sourceMappingURL=materialDropdownList.common.js.map